Navy and black seersucker Classic fit shorts | Men's shorts from Charles Tyrwhitt, Jermyn Street, London
Description: Buy Navy and black seersucker Classic fit shorts from Charles Tyrwhitt of Jermyn Street, London online at ctshirts.co.uk or order our catalogue today
Keywords: Mens's Shirts, women's shirts, ties, suits, shoes, casual wear, outer wear, accessories, belts, boxer shorts, cufflinks, coats, jackets, underwear, briefs, charles tyrwhitt, ctshirts, tyrwhitt, ct shirts, c t shirts, charles tyrwitt, charles ty, charles thyrwitt, charles tyrwhitt shirts, charlestyrwhitt

- Jump to main content
- Jump to main navigation

- 0344 482 4000
- Our stores
- Help

- ## Basket

  Shopping bag

  ## Your shopping bag is empty

  Why not give it a purpose and fill it with clothes and accessories!
- My shortlist

- ## Manage your account

  Log in

###

## Order by 20th Dec to get your gifts in time for Christmas

> Offer information
< Back to previous

# Navy and black seersucker Classic fit shorts

HB095BLK
What's my size?

## Size:

### size: Please select

- 30"
- 32"
- 34"
- 36"
- 38" sold out
- 40" sold out
- 42" sold out
- 44" sold out

## Quantity:

£34.95
95%(36 reviews)
+ Add to shortlist

> "Dark seersucker shorts give you an original alternative to more standard summer fare. They look really rather good especially with polos or our white seersucker shirt."

Nicholas Charles Tyrwhitt Wheeler Founder & owner

## Product details

### Other details

- 100% cotton
- Corozo nut buttons
- Inside leg 24.9cm
- Seersucker textured fabric
- Machine washable at 40 degrees

### Standard shipping £4.95

- From receipt of order we aim to deliver within 5 working days.

More about delivery timescales

### Last order dates for Christmas

- Standard delivery, order by Sunday, 20th December (for alterations, order by Wednesday, 16th December)

- Express delivery, order by Tuesday, 22nd December 6pm GMT (for alterations, order by Sunday, 20th December)

### Our 6 months no quibble returns policy

- We want you to love our products as much as we do but if you don't then you can send them back to us within six months of purchase.

Full details of returns policy

### 100% of customers liked this product (36 reviews)

Posted | Rating | Comment | Company comment
--- | --- | --- | ---
| view all reviews
26-Jul-2015 | Excellent | Easy to order, good quality products, great customer service and highly efficient delivery. |
24-Jul-2015 | Excellent | Great quality just a little on the small side |
20-Jul-2015 | Excellent | the service was timely. Part of the order was not in stock but I was kept fully informed at to its arrival time. |
19-Jul-2015 | Excellent | Excellent quality and fit |
18-Jul-2015 | Excellent | Good quality and good fit, |
18-Jul-2015 | Good | Great fit |
17-Aug-2015 | Excellent | Top quality & fit |
29-Jul-2015 | Excellent | Normally excellent, in this case there was a minor glitch in the order - a shirt ordered as single cuff came as double cuff. |

Share This